from .behaviors import type_in_element
from .analysis import summarize_typing, summarize_typing_async, print_typing_summary
from .telemetry import recorder, get_keyboard_recorder

__all__ = [
    "type_in_element",
    "summarize_typing",
    "summarize_typing_async",
    "print_typing_summary",
    "recorder",
    "get_keyboard_recorder",
]
